@@ -6,4 +6,6 @@ from winky.template_json import TemplateJSON
 from winky.template_text import TemplateText
 from winky.new_project import NewProject
 from winky.database_postgre import Postgre
+from winky.database_oracle import Oracle
+from winky.database_mysql import MySQL
 from time import sleep
